@@ -40,10 +40,7 @@ id <- function(.variables, drop = FALSE) {
   p <- length(ids)
 
   # Calculate dimensions
-  ndistinct <- vapply(ids, attr, "n",
-    FUN.VALUE = numeric(1),
-    USE.NAMES = FALSE
-  )
+  ndistinct <- vapply(ids, attr, "n", FUN.VALUE = numeric(1), USE.NAMES = FALSE)
 
   n <- prod(ndistinct)
   if (n > 2^31) {
@@ -59,7 +56,6 @@ id <- function(.variables, drop = FALSE) {
   }
   attr(res, "n") <- n
 
-
   if (drop) {
     id_var(res, drop = TRUE)
   } else {
