@@ -1,3 +1,4 @@
+# fmt: skip
 x <- tibble::tribble(
   ~chrom, ~start, ~end, ~name, ~score, ~strand,
   "chr1", 500, 1000, ".", ".", "+",
@@ -10,15 +11,21 @@ test_that("glyphs are rendered", {
 
 test_that("glyph labels are applied", {
   res <- bed_glyph(bed_merge(x, id = dplyr::n()), label = "id")
-  expect_equal(res$labels$label, "id")
+  if ("get_labs" %in% getNamespaceExports("ggplot2")) {
+    expect_equal(ggplot2::get_labs(res)$label, "id")
+  } else {
+    expect_equal(res$labels$label, "id")
+  }
 })
 
+# fmt: skip
 a <- tibble::tribble(
   ~chrom, ~start, ~end,
   "chr1", 25, 50,
   "chr1", 100, 125
 )
 
+# fmt: skip
 b <- tibble::tribble(
   ~chrom, ~start, ~end, ~value,
   "chr1", 30, 75, 50
@@ -28,6 +35,7 @@ test_that("expr arguments do not need to be x and/or y", {
   expect_doppelganger("intersect glyph is ok", bed_glyph(bed_intersect(a, b)))
 })
 
+# fmt: skip
 genome <- tibble::tribble(
   ~chrom, ~size,
   "chr1", 1e6
