@@ -1,11 +1,16 @@
 test_that("invalid column names throw error", {
+  # fmt: skip
   x <- tibble::tribble(
     ~pork, ~pie, ~hat,
     "chr1", 1, 50
   )
-  expect_error(check_interval(x), "expected 3 required names, missing: chrom, start, and end")
+  expect_error(
+    check_interval(x),
+    "expected 3 required names, missing: chrom, start, and end"
+  )
 
   # missing 1 only
+  # fmt: skip
   x <- tibble::tribble(
     ~chrom, ~start, ~oops,
     "chr1", 1, 50
@@ -14,14 +19,19 @@ test_that("invalid column names throw error", {
 })
 
 test_that("invalid column names throw error", {
+  # fmt: skip
   genome <- tibble::tribble(
     ~foo, ~bar,
     "chr1", 1e4
   )
-  expect_error(check_genome(genome), "expected 2 required names, missing: chrom and size")
+  expect_error(
+    check_genome(genome),
+    "expected 2 required names, missing: chrom and size"
+  )
 })
 
 test_that("duplicate chromosomes refs throw error", {
+  # fmt: skip
   genome <- tibble::tribble(
     ~chrom, ~size,
     "chr1", 1e4,
